From 035d47340a9feb2948bb9778dd747bed475478c0 Mon Sep 17 00:00:00 2001
From: Ian James Watson <ian.watson@hep.phys.s.u-tokyo.ac.jp>
Date: Fri, 12 Feb 2016 11:47:09 +0900
Subject: [PATCH] Add Relations between TrackCands and the VXD/CDC tracks in TrackMerger

---
 .../vxdCDCTrackMerger/src/VXDCDCTrackMergerModule.cc     | 16 +++++++++++++++-
 1 file changed, 15 insertions(+), 1 deletion(-)

diff --git a/tracking/modules/vxdCDCTrackMerger/src/VXDCDCTrackMergerModule.cc b/tracking/modules/vxdCDCTrackMerger/src/VXDCDCTrackMergerModule.cc
index 0dd52ec..7ae9735 100644
--- a/tracking/modules/vxdCDCTrackMerger/src/VXDCDCTrackMergerModule.cc
+++ b/tracking/modules/vxdCDCTrackMerger/src/VXDCDCTrackMergerModule.cc
@@ -74,6 +74,9 @@ void VXDCDCTrackMergerModule::initialize()
 
   m_TrackCands.registerInDataStore(m_mergedGFTrackCandsColName);
 
+  m_TrackCands.registerRelationTo(m_CDCGFTracks);
+  m_TrackCands.registerRelationTo(m_VXDGFTracks);
+
   m_CDC_wall_radius     = 16.25;
   m_total_pairs         = 0;
   m_total_matched_pairs = 0;
@@ -243,11 +246,17 @@ void VXDCDCTrackMergerModule::collectMergedTrackCands(void)
 
   m_TrackCands.create();
 
+  // Relations
+
+  RelationArray candsToCdcTracks(m_TrackCands, m_CDCGFTracks);
+  RelationArray candsToVxdTracks(m_TrackCands, m_VXDGFTracks);
+
   int nVXDonly(0);
   int nCDConly(0);
   int nMerged(0);
   // first: add VXD tracks (merged with CDC or unmerged)
-  for (int i = 0 ; i < m_VXDGFTrackCands.getEntries() ; i++) {
+  int combinedIdx = 0;
+  for (int i = 0 ; i < m_VXDGFTrackCands.getEntries() ; i++, combinedIdx++) {
 
     auto VXDGFTrackCand = m_VXDGFTrackCands[i];
 
@@ -259,6 +268,7 @@ void VXDCDCTrackMergerModule::collectMergedTrackCands(void)
       continue;
     }
     const genfit::Track* VXDGFTrack = relation1 -> to ;  // this is the VXD fitted track
+    candsToVxdTracks.add(combinedIdx, relation1->indexTo);
 
     auto relation2 = relMatchedTracks.getFirstElementTo(VXDGFTrack);
     if (! relation2) { // VXD track without a CDC match
@@ -267,6 +277,7 @@ void VXDCDCTrackMergerModule::collectMergedTrackCands(void)
     }
 
     const genfit::Track* CDCGFTrack = relation2 -> from ;  // this is the CDC track
+    candsToCdcTracks.add(combinedIdx, relation2->indexFrom);
 
     auto relation3 = CDCTrackCandToTrack.getFirstElementTo(CDCGFTrack);
     if (! relation3) {
@@ -300,6 +311,9 @@ void VXDCDCTrackMergerModule::collectMergedTrackCands(void)
     const genfit::TrackCand* CDCGFTrackCand = relation -> from ;  // this is the CDC pattern
 
     m_TrackCands.appendNew(*CDCGFTrackCand);
+    candsToCdcTracks.add(combinedIdx, relation->indexTo);
+    combinedIdx++; // only increments when we've appended a new track
+
     nCDConly++;
   }
 
-- 
2.2.3

